==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.md <==
# AwsCloudDigitalInterface


```text
aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface
```

```text
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')
```



| Illustration | AwsCloudDigitalInterface | AwsCloudDigitalInterfaceCard | AwsCloudDigitalInterfaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.png) | ![illustration for AwsCloudDigitalInterface](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.Local.png) | ![illustration for AwsCloudDigitalInterfaceCard](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterfaceCard.Local.png) | ![illustration for AwsCloudDigitalInterfaceGroup](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterfaceGroup.Local.png) |




## AwsCloudDigitalInterface

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterface
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterface('AwsCloudDigitalInterface', 'Aws Cloud Digital Interface', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterface
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterface('AwsCloudDigitalInterface', 'Aws Cloud Digital Interface', 'an optional tech label')
@enduml
```

## AwsCloudDigitalInterfaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceCard
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceCard('AwsCloudDigitalInterfaceCard', 'Aws Cloud Digital Interface Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceCard
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceCard('AwsCloudDigitalInterfaceCard', 'Aws Cloud Digital Interface Card', 'an optional description')
@enduml
```

## AwsCloudDigitalInterfaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceGroup
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceGroup('AwsCloudDigitalInterfaceGroup', 'Aws Cloud Digital Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceGroup
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceGroup('AwsCloudDigitalInterfaceGroup', 'Aws Cloud Digital Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.md <==
# AwsCloudDigitalInterface


```text
aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface
```

```text
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')
```



| Illustration | AwsCloudDigitalInterface | AwsCloudDigitalInterfaceCard | AwsCloudDigitalInterfaceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.png) | ![illustration for AwsCloudDigitalInterface](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface.Local.png) | ![illustration for AwsCloudDigitalInterfaceCard](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterfaceCard.Local.png) | ![illustration for AwsCloudDigitalInterfaceGroup](../../../aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterfaceGroup.Local.png) |




## AwsCloudDigitalInterface

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterface
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterface('AwsCloudDigitalInterface', 'Aws Cloud Digital Interface', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterface
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterface('AwsCloudDigitalInterface', 'Aws Cloud Digital Interface', 'an optional tech label')
@enduml
```

## AwsCloudDigitalInterfaceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceCard
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceCard('AwsCloudDigitalInterfaceCard', 'Aws Cloud Digital Interface Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceCard
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceCard('AwsCloudDigitalInterfaceCard', 'Aws Cloud Digital Interface Card', 'an optional description')
@enduml
```

## AwsCloudDigitalInterfaceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceGroup
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceGroup('AwsCloudDigitalInterfaceGroup', 'Aws Cloud Digital Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudDigitalInterfaceGroup
include('aws-q3-2021/Resource/MediaServices/AwsCloudDigitalInterface')

' renders the element
AwsCloudDigitalInterfaceGroup('AwsCloudDigitalInterfaceGroup', 'Aws Cloud Digital Interface Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
